Description
This function calls fslmathsUsage
fslmaths(file, outfile = NULL, retimg = FALSE, reorient = FALSE,
intern = TRUE, opts = "", ...)
Arguments
file
(character) image to be manipulated
outfile
(character) resultant image name (optional)
retimg
(logical) return image of class nifti
reorient
(logical) If retimg, should file be reoriented when read in?
Passed to readNIfTI. intern
(logical) to be passed to system opts
(character) operations to be passed to fslmaths
Value
- If
retimg then object of class nifti. Otherwise,
Result from system command, depends if intern is TRUE or FALSE.