Learn R Programming

fslr (version 1.1)

fslval: Get value from FSL header

Description

This function calls fslval to obtain a nifti header

Usage

fslval(file, keyword = "")

Arguments

file
(character) image filename or character of class nifti
keyword
(character) keyword to be taken from fslhd

Value

  • Character of infromation from fslhd field specified in keyword