Learn R Programming

fslr (version 1.3)

fnirt_with_affine: Register using FNIRT, but doing Affine Registration as well

Description

This function calls fnirt to register infile to reffile and either saves the image or returns an object of class nifti, but does the affine registration first

Usage

fnirt_with_affine(infile, reffile, flirt.omat = NULL, flirt.outfile = NULL,
  outfile = NULL, retimg = FALSE, reorient = FALSE, intern = TRUE,
  flirt.opts = "", opts = "", verbose = TRUE, ...)

Arguments

infile
(character) input filename
reffile
(character) reference image to be registered to
flirt.omat
(character) Filename of output affine matrix
flirt.outfile
(character) Filename of output affine-registered image
outfile
(character) output filename
retimg
(logical) return image of class nifti
reorient
(logical) If retimg, should file be reoriented when read in? Passed to readNIfTI.
intern
(logical) pass to system
flirt.opts
(character) additional options to FLIRT
opts
(character) additional options to FNIRT
verbose
(logical) print out command before running
...
additional arguments passed to readNIfTI.

Value

  • character or logical depending on intern